# New in 0.16.3 (2022-06-04)

## Changes

-   Removes sphinx max version and removes jinja dependency ([#1555]).

## Breaking changes

## Bug Fixes

-   Upper bounds protobuf due to pytorch lightning incompatibilities ([#1556]). Note that [#1556] has unique changes as PyTorch Lightning >=1.6.4 adds the upper bound in their requirements.

## Contributors

-   [@jjhong922]
-   [@adamgayoso]

[#1551]: https://github.com/scverse/scvi-tools/issues/1551
[#1555]: https://github.com/YosefLab/scvi-tools/pull/1555
[#1556]: https://github.com/YosefLab/scvi-tools/pull/1556
[@adamgayoso]: https://github.com/adamgayoso
[@jjhong922]: https://github.com/jjhong922
